Class: Discorb::ApplicationCommand::Command Abstract
- Inherits:
-
DiscordModel
- Object
- DiscordModel
- Discorb::ApplicationCommand::Command
- Defined in:
- lib/discorb/app_command/command.rb
Overview
This class is abstract.
Represents a application command.
Direct Known Subclasses
Defined Under Namespace
Classes: GroupCommand, SlashCommand, SubcommandGroup
Instance Attribute Summary collapse
-
#block ⇒ Proc
readonly
The block of the command.
-
#guild_ids ⇒ Array<#to_s>
readonly
The guild ids that the command is enabled in.
-
#id_map ⇒ Discorb::Dictionary{Discorb::Snowflake, :global => Discorb::Snowflake}
readonly
The ID mapping.
-
#name ⇒ String
readonly
The name of the command.
-
#type ⇒ :chat_input, ...
readonly
The type of the command.
-
#type_raw ⇒ Integer
readonly
The raw type of the command.
Method Summary
Methods inherited from DiscordModel
Instance Attribute Details
#block ⇒ Proc (readonly)
Returns The block of the command.
18 19 20 |
# File 'lib/discorb/app_command/command.rb', line 18 def block @block end |
#guild_ids ⇒ Array<#to_s> (readonly)
Returns The guild ids that the command is enabled in.
16 17 18 |
# File 'lib/discorb/app_command/command.rb', line 16 def guild_ids @guild_ids end |
#id_map ⇒ Discorb::Dictionary{Discorb::Snowflake, :global => Discorb::Snowflake} (readonly)
Returns The ID mapping.
24 25 26 |
# File 'lib/discorb/app_command/command.rb', line 24 def id_map @id_map end |
#name ⇒ String (readonly)
Returns The name of the command.
14 15 16 |
# File 'lib/discorb/app_command/command.rb', line 14 def name @name end |
#type ⇒ :chat_input, ... (readonly)
Returns The type of the command.
20 21 22 |
# File 'lib/discorb/app_command/command.rb', line 20 def type @type end |
#type_raw ⇒ Integer (readonly)
Returns The raw type of the command.
22 23 24 |
# File 'lib/discorb/app_command/command.rb', line 22 def type_raw @type_raw end |