Class: Discorb::Gateway::IntegrationDeleteEvent

Inherits:
GatewayEvent
  • Object
show all
Defined in:
lib/discorb/gateway_events.rb

Overview

Represents a INTEGRATION_DELETE event.

Instance Attribute Summary collapse

Method Summary

Methods inherited from GatewayEvent

#inspect

Instance Attribute Details

#guildnil, Discorb::Guild (readonly)

Note:

This method returns an object from client cache. it will return nil if the object is not in cache.

Returns:

  • The object wasn't cached.

  • The guild of the integration.



# File 'lib/discorb/gateway_events.rb', line 128


#idDiscorb::Snowflake (readonly)

Returns The ID of the integration.

Returns:

  • The ID of the integration.



126
127
128
# File 'lib/discorb/gateway_events.rb', line 126

def id
  @id
end

#usernil, Discorb::User (readonly)

Note:

This method returns an object from client cache. it will return nil if the object is not in cache.

Returns:

  • The object wasn't cached.

  • The user associated with the integration.



# File 'lib/discorb/gateway_events.rb', line 128