Class: Discorb::Gateway::UnknownDeleteBulkMessage

Inherits:
GatewayEvent
  • Object
show all
Defined in:
lib/discorb/gateway.rb

Overview

Represents a message but it has only ID.

Instance Attribute Summary collapse

Method Summary

Methods inherited from GatewayEvent

#inspect

Instance Attribute Details

#channelnil, Discorb::Channel (readonly)

Note:

This method returns an object from client cache. it will return nil if the object is not in cache.



# File 'lib/discorb/gateway.rb', line 379


#guildnil, Discorb::Guild (readonly)

Note:

This method returns an object from client cache. it will return nil if the object is not in cache.



# File 'lib/discorb/gateway.rb', line 379


#idDiscorb::Snowflake (readonly)



377
378
379
# File 'lib/discorb/gateway.rb', line 377

def id
  @id
end